==> haskell-tasty-th-0.1.7-116-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tasty-th.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 tasty-th
version:              0.1.7
visibility:           public
id:                   tasty-th-0.1.7-pp3MpZfUkC1LItybMuQ8Y
key:                  tasty-th-0.1.7-pp3MpZfUkC1LItybMuQ8Y
license:              BSD-3-Clause
maintainer:           Benno Fünfstück <benno.fuenfstueck@gmail.com>
author:               Oscar Finnsson & Emil Nordling & Benno Fünfstück
homepage:             http://github.com/bennofs/tasty-th
synopsis:             Automatic tasty test case discovery using TH
description:
    Generate tasty TestTrees automatically with TemplateHaskell. See the README for example usage.

category:             Testing
abi:                  38e5d44eeb430b30bb715d549a769385
exposed:              True
exposed-modules:      Test.Tasty.TH
import-dirs:          /usr/lib/ghc-8.10.1/site-local/tasty-th-0.1.7
library-dirs:         /usr/lib/ghc-8.10.1/site-local/tasty-th-0.1.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/tasty-th-0.1.7
hs-libraries:         HStasty-th-0.1.7-pp3MpZfUkC1LItybMuQ8Y
depends:
    base-4.14.0.0 haskell-src-exts-1.23.1-InQjJWw3CYQJfZDPuLGUzS
    tasty-1.3.1-EXdIBhC9GRtHkkYb0hINbJ template-haskell-2.16.0.0

haddock-interfaces:   /usr/share/doc/haskell-tasty-th/html/tasty-th.haddock
haddock-html:         /usr/share/doc/haskell-tasty-th/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tasty-th-0.1.7-117-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tasty-th.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 tasty-th
version:              0.1.7
visibility:           public
id:                   tasty-th-0.1.7-7FMeEfciYfXJLFpLm7HyfP
key:                  tasty-th-0.1.7-7FMeEfciYfXJLFpLm7HyfP
license:              BSD-3-Clause
maintainer:           Benno Fünfstück <benno.fuenfstueck@gmail.com>
author:               Oscar Finnsson & Emil Nordling & Benno Fünfstück
homepage:             http://github.com/bennofs/tasty-th
synopsis:             Automatic tasty test case discovery using TH
description:
    Generate tasty TestTrees automatically with TemplateHaskell. See the README for example usage.

category:             Testing
abi:                  58bd9d12a67d79ed6625e6d897454d35
exposed:              True
exposed-modules:      Test.Tasty.TH
import-dirs:          /usr/lib/ghc-8.10.2/site-local/tasty-th-0.1.7
library-dirs:         /usr/lib/ghc-8.10.2/site-local/tasty-th-0.1.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/tasty-th-0.1.7
hs-libraries:         HStasty-th-0.1.7-7FMeEfciYfXJLFpLm7HyfP
depends:
    base-4.14.1.0 haskell-src-exts-1.23.1-vCmNG3acn3Fm5zlP9UadD
    tasty-1.3.1-EzZAP6lOvmbAcy0eUWx1QA template-haskell-2.16.0.0

haddock-interfaces:   /usr/share/doc/haskell-tasty-th/html/tasty-th.haddock
haddock-html:         /usr/share/doc/haskell-tasty-th/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
